@@ -38,7 +38,7 @@
 #' @export
 #' 
 #' @importFrom dplyr %>%
-#' @importFrom dplyr across where
+#' @importFrom dplyr across
 #'
 #' @examples
 #' if(requireNamespace("leaflet")){
@@ -134,6 +134,49 @@ setwd(outPath) #directory of work
 
   # data$IDall <- paste0(1:nrow(data)) #to add an ID by row
 
+  
+
+##### 0.4 leaflet test ####
+###### a. test ####
+# Check if leaflet is installed
+# TRUE if leaflet is found
+suppressWarnings(
+  suggestedTest <- system.file(package='leaflet') %>% 
+    stringr::str_count() > 0 
+)
+
+###### b. leaflet ####
+if(suggestedTest == FALSE){
+  # Set up instructions for download on fail
+  instructions <- paste(" Please try installing the package for yourself", 
+                        "using the following command: \n",
+                        "install.packages(\"leaflet\")")
+  # Set up fail function for tryCatch
+  error_func <- function(e){
+    stop(paste("Failed to install the leaflet package.\n", 
+               instructions))
+  }
+  # Begin interactive input
+  input <- 1
+  if (interactive()){
+    input <- utils::menu(c("Yes", "No"), 
+                         title = paste0("Install the leaflet package? \n"))
+  }
+  if(input == 1){
+    # Start leaflet install
+    message("Installing the leaflet package.")
+    tryCatch(
+      utils::install.packages("leaflet"), 
+      error = error_func, warning = error_func)
+  } # END input == 1
+  
+  else{
+    stop(writeLines(paste("The leaflet package is necessary for BeeBDC::interactiveMapR.\n", 
+                          instructions)))
+  } # END else
+} # END suggestedTest == FALSE
+
+
   #### 1.0 Data prep ####
     ##### 1.1 Remove na+ ####
 data <- data %>%
@@ -248,7 +291,7 @@ speciesList <- speciesList[complete.cases(speciesList)]
 
 options(encoding = "UTF-8")
 
-data <- data %>% dplyr::mutate(dplyr::across(where(is.character), 
+data <- data %>% dplyr::mutate(dplyr::across(tidyselect::where(is.character), 
                               function(x){iconv(x, 
                                                 to = "UTF-8",
                                                 sub = "")}))
